@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
 # @Time    : 2021-07-30 20:14
 # @Author  : zbmain
-__version__ = '0.0.7'
+__version__ = '0.0.9'
 __author__ = 'winwin'
 
 from . import env
-from .utils import func_util
-from .utils import os_util
-from .utils import str_util
 from .utils import support
+from .utils import os_util
 from .utils.func_util import view_df
 
-__all__ = ['env', 'support', 'os_util', 'str_util', 'func_util', 'view_df']
+__all__ = ['env', 'support', 'os_util', 'view_df']
