@@ -43,5 +43,14 @@ def set_seed(seed: int = 1990):
     try:
         import tensorflow
         tensorflow.random.set_seed(seed)
+        tensorflow.set_random_seed(seed)
+    except:
+        pass
+
+    try:
+        import torch
+        torch.manual_seed(seed)  # cpu
+        torch.cuda.manual_seed(seed)  # gpu
+        torch.cuda.manual_seed_all(seed)  # all gpu
     except:
         pass
