@@ -19,20 +19,25 @@ import logging
 import os
 from urllib.parse import urlparse, parse_qs
 
-from dotenv import load_dotenv
+from dotenv import load_dotenv as __load_dotenv
 
 # 项目.跟目录
-CURRENT_DIR = os.path.join(os.path.abspath('.'), '')
+CURRENT_DIR = os.path.abspath('.')
 # 项目.跟目录创建.cache
-CACHE_DIR = os.path.join(CURRENT_DIR, '.cache')
-if not os.path.isdir(CACHE_DIR):
-    os.mkdir(CACHE_DIR)
+CURRENT_CACHE_DIR = os.path.join(CURRENT_DIR, '.cache')
+if not os.path.isdir(CURRENT_CACHE_DIR):
+    os.mkdir(CURRENT_CACHE_DIR)
+
+try:
+    from ..env import __HUB_HOME_DIR
+except:
+    __HUB_HOME_DIR = '.winwin_hub'
 
 
-def get_exists_file(file: str):
+def __get_exists_file(file: str):
     """查找目录优先级: support.py目录 > project跟目录 > HOME环境目录(~/.winwin_hub)"""
     dirs = [os.path.dirname(os.path.abspath(__file__)), os.path.abspath('.'),
-            os.path.join(os.path.expanduser('~'), '.winwin_hub')]
+            os.path.join(os.path.expanduser('~'), __HUB_HOME_DIR)]
     for _dir in dirs:
         filepath = os.path.join(_dir, file)
         if os.path.exists(filepath):
@@ -40,8 +45,8 @@ def get_exists_file(file: str):
 
 
 # 文件目录、项目跟目录、HOME环境目录, 加载.env环境文件
-env_file = get_exists_file('.env')
-env_file and load_dotenv(env_file)
+env_file = __get_exists_file('.env')
+env_file and __load_dotenv(env_file)
 logging.info("current env file used path:[%s]" % env_file)
 
 
@@ -84,7 +89,7 @@ def oss_connect(name="OSS_URI", bucket: str = ''):
                        bucket or config['bucket'])
 
 
-def oss_get_object_cache(url, bucket=None):
+def oss_get_object_cache(url, bucket=None, CACHE_DIR: str = CURRENT_CACHE_DIR):
     """下载 OSS文件到缓存目录"""
     bucket = bucket or oss_connect()
     cache_file = os.path.join(CACHE_DIR, os.path.basename(url))
@@ -121,6 +126,20 @@ def oss_upload_object(file_url, oss_url, bucket=None):
     return '%s%s/%s' % ('oss://', bucket.bucket_name, oss_url)
 
 
+def oss_file2DF(oss_file: str, bucket=None, sep: str = None):
+    """注意文件必须是表格文件"""
+    import pandas
+    suffix = os.path.splitext(oss_file)[1]
+    content = oss_get_object_stream(oss_file, bucket)
+    if suffix == '.xlsx':
+        return pandas.read_excel(content)
+    else:
+        sep = sep or (',' if suffix == '.csv' else '\t' if suffix == '.tsv' else ',')
+        lines = str(content.decode()).strip().split('\n')
+        header, data = lines[0].split(sep), list(map(lambda x: str(x).split(sep), lines[1:]))
+        return pandas.DataFrame(data, columns=header)
+
+
 # ODPS
 ODPS_TUNNEL, ODPS_LIMIT = True, False
 
@@ -221,18 +240,18 @@ def parse_redis_uri(uri):
     }
 
 
-redis_pool = None
+__redis_pool = None
 
 
 def redis_connect(name="REDIS_URI"):
     """Redis Connect"""
     import redis
-    global redis_pool
+    global __redis_pool
     redis_uri = parse_redis_uri(os.environ[name])
-    if not (redis_pool and redis_pool.connection_kwargs['host'] == redis_uri['host'] \
-            and redis_pool.connection_kwargs['db'] == redis_uri['db']):
-        redis_pool = redis.ConnectionPool(**redis_uri)
-    return redis.StrictRedis(connection_pool=redis_pool)
+    if not (__redis_pool and __redis_pool.connection_kwargs['host'] == redis_uri['host'] \
+            and __redis_pool.connection_kwargs['db'] == redis_uri['db']):
+        __redis_pool = redis.ConnectionPool(**redis_uri)
+    return redis.StrictRedis(connection_pool=__redis_pool)
 
 
 def parse_nebula_uri(uri=None):
@@ -250,18 +269,18 @@ def parse_nebula_uri(uri=None):
     }
 
 
-nebula_pool = None
+__nebula_pool = None
 
 
 def nebula_connect(name='NEBULA_URI'):
     uri = parse_nebula_uri(os.environ[name])
     from nebula3.gclient.net import ConnectionPool
     from nebula3.Config import Config
-    global nebula_pool
-    if not nebula_pool:
-        nebula_pool = ConnectionPool()
-        nebula_pool.init(uri['servers'], Config())
-    session = nebula_pool.get_session(uri['username'], uri['password'])
+    global __nebula_pool
+    if not __nebula_pool:
+        __nebula_pool = ConnectionPool()
+        __nebula_pool.init(uri['servers'], Config())
+    session = __nebula_pool.get_session(uri['username'], uri['password'])
     session.space, session.comment, session.heart_beat = uri['space'], uri['comment'], uri['heart_beat']
     return session
 
